/**
 * Execute a sequence of operations.
 * Wraps `language-common/execute`, and prepends initial state for mysql.
 * @private
 * @param {Operations} operations - Operations to be performed.
 * @returns {Operation}
 */
export function execute(...operations: Operations): Operation;
/**
 * Insert a record
 * @example <caption>Insert a record into the `users` table</caption>
 * insert("users", { name: (state) => state.data.name });
 * @function
 * @public
 * @param {string} table - The target table
 * @param {object} fields - A fields object
 * @returns {Operation}
 */
export function insert(table: string, fields: object): Operation;
/**
 * Insert or Update a record if matched
 * @example <caption>Upsert a record</caption>
 * upsert("table", { name: (state) => state.data.name });
 * @function
 * @public
 * @param {string} table - The target table
 * @param {object} fields - A fields object
 * @returns {Operation}
 */
export function upsert(table: string, fields: object): Operation;
/**
 * Insert or update multiple records using ON DUPLICATE KEY
 * @public
 * @example <caption>Upsert multiple records</caption>
 * upsertMany(
 *   'users', // the DB table
 *   [
 *     { name: 'one', email: 'one@openfn.org' },
 *     { name: 'two', email: 'two@openfn.org' },
 *   ]
 * )
 * @function
 * @public
 * @param {string} table - The target table
 * @param {array} data - An array of objects or a function that returns an array
 * @returns {Operation}
 */
export function upsertMany(table: string, data: any[]): Operation;
/**
 * Execute a SQL statement
 * @example <caption>Execute a SQL statement</caption>
 * query({ sql: 'select * from users;' })
 * @function
 * @public
 * @param {object} options - Payload data for the message
 * @returns {Operation}
 */
export function query(options: object): Operation;
/**
 * Execute a SQL statement
 * @example <caption>Execute a SQL statement</caption>
 * sqlString(state => "select * from items;")
 * @function
 * @public
 * @param {String} queryString - A query string (or function which takes state and returns a string)
 * @returns {Operation}
 */
export function sqlString(queryString: string): Operation;
export { fn, fnIf, each, http, merge, field, fields, cursor, dateFns, combine, dataPath, dataValue, alterState, sourceValue, arrayToString, lastReferenceValue } from "@openfn/language-common";
